==> 0.0.4.tar.gz: android/src/main/java/com/edulade/ccavenue_payment_gateway/CcavenuePaymentGatewayPlugin.java <==
package com.edulade.ccavenue_payment_gateway;

import android.app.Activity;
import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import android.content.Intent;

/** CcavenuePaymentGatewayPlugin */
public class CcavenuePaymentGatewayPlugin implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  public String accessCode, merchantId, currencyType, amount, orderId, rsaKeyUrl, redirectUrl, cancelUrl,transUrl;
  private Activity activity;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "ccavenue_payment_gateway");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    }
    else if (call.method.equals("CC_Avenue")) {
      transUrl = call.argument("transUrl");
      rsaKeyUrl = call.argument("rsaKeyUrl");
      accessCode = call.argument("accessCode");
      merchantId = call.argument("merchantId");
      orderId = call.argument("orderId");
      currencyType = call.argument("currencyType");
      amount = call.argument("amount");
      cancelUrl = call.argument("cancelUrl");
      redirectUrl = call.argument("redirectUrl");
      CcavenuePaymentGatewayInit();
    } else {
      result.notImplemented();
    }
  }


  public void CcavenuePaymentGatewayInit(){
    Intent intent = new Intent(this.activity, WebViewActivity.class);
    intent.putExtra(AvenuesParams.ACCESS_CODE, accessCode);
    intent.putExtra(AvenuesParams.MERCHANT_ID, merchantId);
    intent.putExtra(AvenuesParams.ORDER_ID, orderId);
    intent.putExtra(AvenuesParams.CURRENCY,currencyType );
    intent.putExtra(AvenuesParams.AMOUNT, amount);
    intent.putExtra(AvenuesParams.REDIRECT_URL, redirectUrl);
    intent.putExtra(AvenuesParams.CANCEL_URL, cancelUrl);
    intent.putExtra(AvenuesParams.RSA_KEY_URL, rsaKeyUrl);
    intent.putExtra(AvenuesParams.TRANS_URL, transUrl);
    this.activity.startActivity(intent);
  }



  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}

==> 0.0.5.tar.gz: android/src/main/java/com/edulade/ccavenue_payment_gateway/CcavenuePaymentGatewayPlugin.java <==
package com.edulade.ccavenue_payment_gateway;

import android.app.Activity;
import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import android.content.Intent;

/** CcavenuePaymentGatewayPlugin */
public class CcavenuePaymentGatewayPlugin implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  public String accessCode, merchantId, currencyType, amount, orderId, rsaKeyUrl, redirectUrl, cancelUrl,transUrl;
  private Activity activity;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "ccavenue_payment_gateway");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    }
    else if (call.method.equals("ccAvenue_gateway_init")) {
      transUrl = call.argument("transUrl");
      rsaKeyUrl = call.argument("rsaKeyUrl");
      accessCode = call.argument("accessCode");
      merchantId = call.argument("merchantId");
      orderId = call.argument("orderId");
      currencyType = call.argument("currencyType");
      amount = call.argument("amount");
      cancelUrl = call.argument("cancelUrl");
      redirectUrl = call.argument("redirectUrl");
      CcavenuePaymentGatewayInit();
    } else {
      result.notImplemented();
    }
  }


  public void CcavenuePaymentGatewayInit(){
    Intent intent = new Intent(this.activity, WebViewActivity.class);
    intent.putExtra(AvenuesParams.ACCESS_CODE, accessCode);
    intent.putExtra(AvenuesParams.MERCHANT_ID, merchantId);
    intent.putExtra(AvenuesParams.ORDER_ID, orderId);
    intent.putExtra(AvenuesParams.CURRENCY,currencyType );
    intent.putExtra(AvenuesParams.AMOUNT, amount);
    intent.putExtra(AvenuesParams.REDIRECT_URL, redirectUrl);
    intent.putExtra(AvenuesParams.CANCEL_URL, cancelUrl);
    intent.putExtra(AvenuesParams.RSA_KEY_URL, rsaKeyUrl);
    intent.putExtra(AvenuesParams.TRANS_URL, transUrl);
    this.activity.startActivity(intent);
  }



  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}
